==> qtjambi-qml-debuginfo-macos-6.5.5.jar: sources/QtJambiQml/metainfo.cpp <==
#include <QtJambi/MetaInfo>


void initialize_meta_info_QQmlListProperty();
void initialize_meta_info_QJSEngine();
void initialize_meta_info_QJSManagedValue();
void initialize_meta_info_QJSNumberCoercion();
void initialize_meta_info_QJSPrimitiveValue();
void initialize_meta_info_QJSValue();
void initialize_meta_info_QJSValueIterator();
void initialize_meta_info_QQmlAbstractUrlInterceptor();
void initialize_meta_info_QQmlApplicationEngine();
void initialize_meta_info_QQmlComponent();
void initialize_meta_info_QQmlContext();
void initialize_meta_info_QQmlContext_PropertyPair();
void initialize_meta_info_QQmlDebuggingEnabler();
void initialize_meta_info_QQmlEngine();
void initialize_meta_info_QQmlEngineExtensionInterface();
void initialize_meta_info_QQmlEngineExtensionPlugin();
void initialize_meta_info_QQmlError();
void initialize_meta_info_QQmlExpression();
void initialize_meta_info_QQmlExtensionInterface();
void initialize_meta_info_QQmlExtensionPlugin();
void initialize_meta_info_QQmlFile();
void initialize_meta_info_QQmlFileSelector();
void initialize_meta_info_QQmlImageProviderBase();
void initialize_meta_info_QQmlIncubationController();
void initialize_meta_info_QQmlIncubator();
void initialize_meta_info_QQmlInfo();
void initialize_meta_info_QQmlListReference();
void initialize_meta_info_QQmlNetworkAccessManagerFactory();
void initialize_meta_info_QQmlParserStatus();
void initialize_meta_info_QQmlProperty();
void initialize_meta_info_QQmlPropertyMap();
void initialize_meta_info_QQmlPropertyValueSource();
void initialize_meta_info_QQmlScriptString();
void initialize_meta_info_QQmlTypesExtensionInterface();
void initialize_meta_info_QtQml();
void initialize_meta_info_QtQml_ObjectCallback();
void initialize_meta_info_QtQml_QQmlAttachedPropertiesFunc();
void initialize_meta_info_QtQml_ValueCallback();

extern "C" Q_DECL_EXPORT jint JNICALL JNI_ONLOAD(JavaVM *, void *)
{
    QTJAMBI_LIBRARY_INITIALIZATION_METHOD_CALL("io.qt.qml")

    initialize_meta_info_QQmlListProperty();
    initialize_meta_info_QJSEngine();
    initialize_meta_info_QJSManagedValue();
    initialize_meta_info_QJSNumberCoercion();
    initialize_meta_info_QJSPrimitiveValue();
    initialize_meta_info_QJSValue();
    initialize_meta_info_QJSValueIterator();
    initialize_meta_info_QQmlAbstractUrlInterceptor();
    initialize_meta_info_QQmlApplicationEngine();
    initialize_meta_info_QQmlComponent();
    initialize_meta_info_QQmlContext();
    initialize_meta_info_QQmlContext_PropertyPair();
    initialize_meta_info_QQmlDebuggingEnabler();
    initialize_meta_info_QQmlEngine();
    initialize_meta_info_QQmlEngineExtensionInterface();
    initialize_meta_info_QQmlEngineExtensionPlugin();
    initialize_meta_info_QQmlError();
    initialize_meta_info_QQmlExpression();
    initialize_meta_info_QQmlExtensionInterface();
    initialize_meta_info_QQmlExtensionPlugin();
    initialize_meta_info_QQmlFile();
    initialize_meta_info_QQmlFileSelector();
    initialize_meta_info_QQmlImageProviderBase();
    initialize_meta_info_QQmlIncubationController();
    initialize_meta_info_QQmlIncubator();
    initialize_meta_info_QQmlInfo();
    initialize_meta_info_QQmlListReference();
    initialize_meta_info_QQmlNetworkAccessManagerFactory();
    initialize_meta_info_QQmlParserStatus();
    initialize_meta_info_QQmlProperty();
    initialize_meta_info_QQmlPropertyMap();
    initialize_meta_info_QQmlPropertyValueSource();
    initialize_meta_info_QQmlScriptString();
    initialize_meta_info_QQmlTypesExtensionInterface();
    initialize_meta_info_QtQml();
    initialize_meta_info_QtQml_ObjectCallback();
    initialize_meta_info_QtQml_QQmlAttachedPropertiesFunc();
    initialize_meta_info_QtQml_ValueCallback();
    return QTJAMBI_ONLOAD_RETURN;
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QtJambi_1LibraryUtilities_internalAccess)(JNIEnv *env, jclass cls){
    jobject result{0};
    QTJAMBI_TRY{
        result = MetaInfoAPI::internalAccess(env, cls);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(env);
    }QTJAMBI_TRY_END
    return result;
}

==> qtjambi-qml-debuginfo-macos-6.8.5.jar: sources/QtJambiQml/metainfo.cpp <==
#include <QtJambi/MetaInfo>


void initialize_meta_info_QQmlListProperty();
void initialize_meta_info_QJSEngine();
void initialize_meta_info_QJSManagedValue();
void initialize_meta_info_QJSNumberCoercion();
void initialize_meta_info_QJSPrimitiveValue();
void initialize_meta_info_QJSValue();
void initialize_meta_info_QJSValueIterator();
void initialize_meta_info_QQmlAbstractUrlInterceptor();
void initialize_meta_info_QQmlApplicationEngine();
void initialize_meta_info_QQmlComponent();
void initialize_meta_info_QQmlContext();
void initialize_meta_info_QQmlContext_PropertyPair();
void initialize_meta_info_QQmlDebuggingEnabler();
void initialize_meta_info_QQmlEngine();
void initialize_meta_info_QQmlEngineExtensionInterface();
void initialize_meta_info_QQmlEngineExtensionPlugin();
void initialize_meta_info_QQmlError();
void initialize_meta_info_QQmlExpression();
void initialize_meta_info_QQmlExtensionInterface();
void initialize_meta_info_QQmlExtensionPlugin();
void initialize_meta_info_QQmlFile();
void initialize_meta_info_QQmlFileSelector();
void initialize_meta_info_QQmlImageProviderBase();
void initialize_meta_info_QQmlIncubationController();
void initialize_meta_info_QQmlIncubator();
void initialize_meta_info_QQmlInfo();
void initialize_meta_info_QQmlListReference();
void initialize_meta_info_QQmlNetworkAccessManagerFactory();
void initialize_meta_info_QQmlParserStatus();
void initialize_meta_info_QQmlProperty();
void initialize_meta_info_QQmlPropertyMap();
void initialize_meta_info_QQmlPropertyValueSource();
void initialize_meta_info_QQmlScriptString();
void initialize_meta_info_QQmlTypesExtensionInterface();
void initialize_meta_info_QtQml();
void initialize_meta_info_QtQml_ObjectCallback();
void initialize_meta_info_QtQml_QQmlAttachedPropertiesFunc();
void initialize_meta_info_QtQml_ValueCallback();

extern "C" Q_DECL_EXPORT jint JNICALL JNI_ONLOAD(JavaVM *, void *)
{
    QTJAMBI_LIBRARY_INITIALIZATION_METHOD_CALL("io.qt.qml")

    initialize_meta_info_QQmlListProperty();
    initialize_meta_info_QJSEngine();
    initialize_meta_info_QJSManagedValue();
    initialize_meta_info_QJSNumberCoercion();
    initialize_meta_info_QJSPrimitiveValue();
    initialize_meta_info_QJSValue();
    initialize_meta_info_QJSValueIterator();
    initialize_meta_info_QQmlAbstractUrlInterceptor();
    initialize_meta_info_QQmlApplicationEngine();
    initialize_meta_info_QQmlComponent();
    initialize_meta_info_QQmlContext();
    initialize_meta_info_QQmlContext_PropertyPair();
    initialize_meta_info_QQmlDebuggingEnabler();
    initialize_meta_info_QQmlEngine();
    initialize_meta_info_QQmlEngineExtensionInterface();
    initialize_meta_info_QQmlEngineExtensionPlugin();
    initialize_meta_info_QQmlError();
    initialize_meta_info_QQmlExpression();
    initialize_meta_info_QQmlExtensionInterface();
    initialize_meta_info_QQmlExtensionPlugin();
    initialize_meta_info_QQmlFile();
    initialize_meta_info_QQmlFileSelector();
    initialize_meta_info_QQmlImageProviderBase();
    initialize_meta_info_QQmlIncubationController();
    initialize_meta_info_QQmlIncubator();
    initialize_meta_info_QQmlInfo();
    initialize_meta_info_QQmlListReference();
    initialize_meta_info_QQmlNetworkAccessManagerFactory();
    initialize_meta_info_QQmlParserStatus();
    initialize_meta_info_QQmlProperty();
    initialize_meta_info_QQmlPropertyMap();
    initialize_meta_info_QQmlPropertyValueSource();
    initialize_meta_info_QQmlScriptString();
    initialize_meta_info_QQmlTypesExtensionInterface();
    initialize_meta_info_QtQml();
    initialize_meta_info_QtQml_ObjectCallback();
    initialize_meta_info_QtQml_QQmlAttachedPropertiesFunc();
    initialize_meta_info_QtQml_ValueCallback();
    return QTJAMBI_ONLOAD_RETURN;
}

extern "C" Q_DECL_EXPORT jobject JNICALL Java_io_qt_qml_QtJambi_1LibraryUtilities_internalAccess(JNIEnv *env, jclass cls){
    jobject result{0};
    QTJAMBI_TRY{
        result = MetaInfoAPI::internalAccess(env, cls);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(env);
    }QTJAMBI_TRY_END
    return result;
}
